<?php
/*
Plugin Name: Amazon ASIN Image Finder
Description: Use this plugin to find the Amazon image you need to use with Erica's theme
Version: 1.3
Author: Jon
*/

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class AmazonASINImageScraperWithHighlight {

    public function __construct() {
        add_shortcode('scrape_amazon_images_table', [$this, 'render_shortcode']);
    }

    public function render_shortcode() {
        ob_start();
        ?>
        <form method="POST">
            <label for="asin">Enter ASIN:</label>
            <input type="text" id="asin" name="asin" required>
            <button type="submit">Scrape Images</button>
        </form>
        <?php

        if ($_SERVER['REQUEST_METHOD'] === 'POST' && !empty($_POST['asin'])) {
            $asin = sanitize_text_field($_POST['asin']);
            $image_urls = $this->scrape_image_urls($asin);

            if (!empty($image_urls)) {
                // Separate URLs with 'SL1500' to highlight and sort them to the top
                $highlighted = array_filter($image_urls, function ($url) {
                    return strpos($url, 'SL1500') !== false;
                });

                $regular = array_filter($image_urls, function ($url) {
                    return strpos($url, 'SL1500') === false;
                });

                $sorted_urls = array_merge($highlighted, $regular);

                echo '<h3>Found Image URLs:</h3>';
                echo '<table style="width: 100%; border-collapse: collapse;">';
                echo '<thead>';
                echo '<tr>';
                echo '<th style="border: 1px solid #ddd; padding: 8px;">Image</th>';
                echo '<th style="border: 1px solid #ddd; padding: 8px;">Image URL</th>';
                echo '</tr>';
                echo '</thead>';
                echo '<tbody>';

                foreach ($sorted_urls as $url) {
                    $highlight = (strpos($url, 'SL1500') !== false) ? 'background-color: yellow;' : '';
                    echo '<tr style="' . $highlight . '">';
                    echo '<td style="border: 1px solid #ddd; padding: 8px; text-align: center;">';
                    echo '<img src="' . esc_url($url) . '" style="max-width: 200px; max-height: 200px;" alt="Amazon Product Image">';
                    echo '</td>';
                    echo '<td style="border: 1px solid #ddd; padding: 8px; font-size: 0.85em; word-wrap: break-word;">';
                    echo esc_url($url);
                    echo '</td>';
                    echo '</tr>';
                }

                echo '</tbody>';
                echo '</table>';
            } else {
                echo '<p>No images found. Please check the ASIN or try again later.</p>';
            }
        }

        return ob_get_clean();
    }

    private function scrape_image_urls($asin) {
        $product_url = "https://www.amazon.co.uk/dp/" . $asin;

        $response = wp_remote_get($product_url);

        if (is_wp_error($response)) {
            return [];
        }

        $html = wp_remote_retrieve_body($response);

        if (empty($html)) {
            return [];
        }

        // Extract image URLs using regular expressions
        preg_match_all('/https:\/\/[^"]+\.media-amazon\.com\/images\/[^"]+/', $html, $matches);

        if (isset($matches[0]) && !empty($matches[0])) {
            // Remove duplicates and return the unique URLs
            return array_unique($matches[0]);
        }

        return [];
    }
}

new AmazonASINImageScraperWithHighlight();
